nio library

Classes

AbstractInterruptibleChannel
Base implementation class for interruptible channels.
AbstractSelectableChannel
Base implementation class for selectable channels.
ByteChannel
A channel that can read and write bytes. This interface simply unifies the {@link ReadableByteChannel} and {@link WritableByteChannel}; it does not specify any new operations.
Closeable
A {@code Closeable} is a source or destination of data that can be closed. The close method is invoked to release resources that the object is holding (such as open files).
DatagramChannel
A selectable channel for datagram-oriented sockets.
InetSocketAddress
This class implements an IP Socket Address (IP address + port number) It can also be a pair (hostname + port number), in which case an attempt will be made to resolve the hostname. If resolution fails then the address is said to be unresolved but can still be used on some circumstances like connecting through a proxy.
InterruptibleChannel
NetworkChannel
A channel to a network socket.
NIOChannel
A nexus for I/O operations.
ReadableByteChannel
A channel that can read bytes.
SelectableChannel
A channel that can be multiplexed via a {@link Selector}.
SocketAddress
This class represents a Socket Address with no protocol attachment. As an abstract class, it is meant to be subclassed with a specific, protocol dependent, implementation.
SocketChannel
A selectable channel for stream-oriented connecting sockets.
WritableByteChannel
A channel that can write bytes.

Exceptions / Errors

ClosedChannelException
Checked exception thrown when an attempt is made to invoke or complete an I/O operation upon channel that is closed, or at least closed to that operation. That this exception is thrown does not necessarily imply that the channel is completely closed. A socket channel whose write half has been shut down, for example, may still be open for reading.
IOError
Thrown when a serious I/O error has occurred.